// EPI2ME Labs brand colours
$brand-primary: #0079a4;
$brand-primary-m: #0084a9a6;
$brand-primary-l: #0084a91a;
$brand-secondary: #0ebbb2;
$brand-tertiary: #00485b;
$brand-black: #333333;
$brand-grey: #666666;
$brand-grey-l: #6666661f;
$brand-dark-grey: #455560;
$brand-light-grey: #B5AEA7;
$brand-red: #BC4B51;
$brand-red-m: #BC4B51a6;
$brand-green: #8CB369;
$brand-pink: #A60067;

// Override bootstrap defaults
$primary:       $brand-primary !default;
$secondary:     $brand-secondary !default;
$dark:          $brand-tertiary !default;

// Adjust corners
$border-radius: 0.375rem;
$enable-negative-margins: true;

@import "data/vendor/bootstrap-5.3.0/scss/bootstrap.scss";

* {
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

// Logo sizing
#logo {
    width: 100%;
    height: auto;
}